# https://github.com/tdsacilowski/hashi-demo/blob/master/shared/nomad/jobs/wordpress.hcl
job "wordpress" {

  update {
    stagger = "10s"
    max_parallel = 1
  }

  group "wordpress" {

    restart {
      interval = "5m"
      attempts = 10
      delay    = "25s"
      mode     = "delay"
    }

    task "wordpress" {
      driver = "podman"

      config {
        image = "wordpress"
        network_mode = "host"
      }

      env {
        WORDPRESS_DB_HOST     = "mysql.service.consul:3306"
        WORDPRESS_DB_PASSWORD = "my-secret-pwd"
      }

      service {
        name = "wordpress"
        tags = ["global"]
        port = "http"

        check {
          name     = "wordpress running on port 80"
          type     = "http"
          protocol = "http"
          path     = "/"
          interval = "10s"
          timeout  = "2s"
        }
      }

      resources {
        cpu = 500
        memory = 256

        network {
          mbits = 10

          port "http" {
            static = 80
          }
        }
      }
    }
  }
}
